CONFIG_PATH = ".jupancon/config.yml"
REDSHIFT_PORT = 5439
REDSHIFT_CHUNKSIZE = 200000
LOCALHOST = "127.0.0.1"
